package net.customware.license.atlassian.restriction;

import net.customware.license.support.simple.SimpleLicenseContent;
import net.customware.license.support.simple.SimpleRestrictionException;

import com.atlassian.license.LicenseType;

/**
 * Checks that the
 * 
 * @author david
 * 
 */
public class LicenseTypeRestriction extends AbstractLicenseRestriction {
    public LicenseTypeRestriction() {
    }

    @Override protected void checkRestriction( Object context, SimpleLicenseContent content, Object attributeValue )
            throws SimpleRestrictionException {
        LicenseType currentLicenseType = getLicense( context ).getLicenseType();
        LicenseType allowedLicenseType = ( LicenseType ) attributeValue;

        if ( currentLicenseType == null )
            throw new SimpleRestrictionException( "Unable to determine the application's current license type." );

        if ( allowedLicenseType == null )
            throw new SimpleRestrictionException( "The license does not specify the license type it requires." );

        if ( !currentLicenseType.equals( allowedLicenseType ) )
            throw new SimpleRestrictionException( "The current license type (" + currentLicenseType.getNiceName()
                    + ") does not match the required license type (" + allowedLicenseType.getNiceName() + ")." );
    }

    public static void setLicenseType( SimpleLicenseContent content, LicenseType licenseType ) {
        content.setAttribute( LicenseTypeRestriction.class, licenseType );
    }
}
